part of 'profile_bloc.dart';

abstract class ProfileEvent extends Equatable {
  const ProfileEvent();

  @override
  List<Object> get props => [];
}

class LoadProfile extends ProfileEvent {
  final String token;
  final int userID;
  const LoadProfile({required this.token, required this.userID});
  @override
  List<Object> get props => [token, userID];
}

class LoadProfileInformation extends ProfileEvent {
  @override
  List<Object> get props => [];
}

class LoadEligibility extends ProfileEvent {
  final List<EligibityCert> eligibilities;
  const LoadEligibility({required this.eligibilities});
  @override
  List<Object> get props => [];
}

class EditEligibility extends ProfileEvent {
  final EligibityCert eligibityCert;
  const EditEligibility({required this.eligibityCert});
  @override
  List<Object> get props => [];
}

class DeleteEligibility extends ProfileEvent {
  final List<EligibityCert> eligibilities;
  final String profileId;
  final int eligibilityId;
  final String token;
  const DeleteEligibility(
      {required this.eligibilities,
      required this.eligibilityId,
      required this.profileId,
      required this.token});
  @override
  List<Object> get props => [eligibilities, profileId, eligibilityId, token];
}

class ShowAddEligibilityForm extends ProfileEvent {

}
class AddEligibility extends ProfileEvent{
  final EligibityCert  eligibityCert;
  final String profileId;
  final String token;
  const AddEligibility({required this.eligibityCert, required this.profileId, required this.token});
  @override
    List<Object> get props => [eligibityCert, profileId, token];
}
